/*
 * Licensed to the Light Team Software (Light Team) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The Light Team licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.lightteam.modpeide.ui.settings.fragments

import android.os.Bundle
import android.view.View
import androidx.navigation.NavController
import androidx.navigation.fragment.findNavController
import androidx.preference.Preference
import androidx.preference.PreferenceFragmentCompat
import com.lightteam.modpeide.R
import com.lightteam.modpeide.data.utils.commons.PreferenceHandler
import com.lightteam.modpeide.utils.extensions.isUltimate

class EditorFragment : PreferenceFragmentCompat() {

    companion object {
        private const val KEY_FONT_TYPE = PreferenceHandler.KEY_FONT_TYPE
        private const val KEY_TAB_LIMIT = PreferenceHandler.KEY_TAB_LIMIT
        private const val KEY_ERROR_HIGHLIGHTING = PreferenceHandler.KEY_ERROR_HIGHLIGHTING
        private const val KEY_KEYBOARD_PRESET = PreferenceHandler.KEY_KEYBOARD_PRESET
    }

    private lateinit var navController: NavController

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        navController = findNavController()
    }

    override fun onCreatePreferences(savedInstanceState: Bundle?, rootKey: String?) {
        setPreferencesFromResource(R.xml.preference_editor, rootKey)

        findPreference<Preference>(KEY_FONT_TYPE)?.setOnPreferenceClickListener {
            val destination = EditorFragmentDirections.toFontsFragment()
            navController.navigate(destination)
            true
        }
        findPreference<Preference>(KEY_TAB_LIMIT)?.isEnabled = isUltimate()
        findPreference<Preference>(KEY_ERROR_HIGHLIGHTING)?.isEnabled = isUltimate()
        findPreference<Preference>(KEY_KEYBOARD_PRESET)?.setOnPreferenceClickListener {
            val destination = EditorFragmentDirections.toPresetsFragment()
            navController.navigate(destination)
            true
        }
    }
}